<?php

/**
 * @file
 * Webform module GOV.UK Pay component.
 */

/**
 * Declare rendering routines for our element.
 *
 * Called by webform to register theme functions that the individual
 * component uses.
 *
 * Implements _webform_theme_COMPONENT().
 */
function _webform_theme_gov_uk_pay() {
  return [
    'webform_gov_uk_pay' => [
      'render element' => 'element',
    ],
  ];
}

/**
 * Implements _webform_defaults_component().
 */
function _webform_defaults_gov_uk_pay() {
  return [
    'name' => '',
    'form_key' => NULL,
    'pid' => 0,
    'weight' => 0,
    'extra' => [
      'amount' => '',
      'amount_source' => '',
      'payment_calculate_summary' => '',
      'confirm_calculate_summary' => '',
      'content' => '',
      'button_text' => '',
      'payment_message' => '',
      'confirmation_message' => '',
    ],
  ];
}

/**
 * Implements _webform_edit_component().
 */
function _webform_edit_gov_uk_pay($component) {

  $form = [];

  $node = node_load($component['nid']);

  $form['amount'] = [
    '#type' => 'fieldset',
    '#title' => t('Amount'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  ];

  $form['amount']['source'] = [
    '#title' => t('Amount Source'),
    '#type' => 'select',
    // Use 'conditional_action_set' filter as it most closely resembles the list of appropriate components.
    '#options' => webform_component_list($node, 'conditional_action_set'),
    '#parents' => ['extra', 'amount_source'],
    '#empty_option' => t(' - Fixed Amount -'),
    '#description' => t('Select an existing component to provide the total payment due. This can be e.g. a number component dropdown, or used with modules such as Webform Calculate.'),
  ];

  $form['amount']['fixed_amount'] = [
    '#type' => 'textfield',
    '#attributes' => [
      ' type' => 'number',
    ],
    '#title' => t('Fixed Amount'),
    '#default_value' => $component['extra']['amount'],
    '#description' => t('Choose the amount that a payment will be made for.'),
    '#parents' => ['extra', 'amount'],
    '#states' => [
      'visible' => [
        ':input[name="extra[amount_source]"]' => ['value' => ''],
      ],
    ],
  ];

  $form['display']['content'] = [
    '#type' => 'textarea',
    '#title' => t('Content'),
    '#default_value' => $component['extra']['content'],
    '#description' => t('Optional content to display on the webform.'),
    '#parents' => ['extra', 'content'],
  ];

  $form['display']['button_text'] = [
    '#type' => 'textfield',
    '#title' => t('Button text'),
    '#default_value' => $component['extra']['button_text'],
    '#description' => t('Optional text to replace the submit button text with.'),
    '#parents' => ['extra', 'button_text'],
  ];

  $form['display']['payment_message'] = [
    '#type' => 'textarea',
    '#title' => t('Payment message'),
    '#default_value' => $component['extra']['payment_message'],
    '#description' => t('Text to display to user once they are redirected to GOV.UK Pay.'),
    '#parents' => ['extra', 'payment_message'],
  ];

  $form['display']['confirmation_message'] = [
    '#type' => 'textarea',
    '#title' => t('Confirmation message'),
    '#default_value' => $component['extra']['confirmation_message'],
    '#description' => t('Text to display to user once they return to the site from GOV.UK Pay.'),
    '#parents' => ['extra', 'confirmation_message'],
  ];

  // Hide name, it's never shown.
  $form['name']['#type'] = 'value';
  // Hack - name is required by webform but we don't expose it to the user.
  // Instead we'll replace it with the value of form_key.
  $form['name']['#value'] = 'gov_uk_pay';
  return $form;
}

/**
 * Implements _webform_render_component().
 */
function _webform_render_gov_uk_pay($component, $value = NULL, $filter = TRUE) {
  $return = [];

  if (module_exists('form_builder_webform')) {
    $cid = $component['cid'];

    $buttonText = isset($component["extra"]["button_text"])
      ? $component["extra"]["button_text"]
      : NULL;

    $messageElement = [
      '#title' => $filter ? webform_filter_xss($component['name']) : $component['name'],
      '#weight' => $component['weight'],
      '#webform_component' => $component,
      '#attributes' => [
        'class' => [
          'gov-pay-message',
        ],
      ],
      '#type' => 'markup',
    ];

    $message = !empty($component["extra"]["content"])
      ? $component["extra"]["content"]
      : '';

    $messageElement['#markup'] = $message;

    $return = $messageElement;
  }

  return $return;
}

/**
 * Form Builder specific hooks.
 */

/**
 * Implements _form_builder_webform_form_builder_types_component().
 */
function _form_builder_webform_form_builder_types_gov_uk_pay() {
  $fields = [];

  $fields['gov_uk_pay'] = [
    'title' => t('Gov Pay'),
    'weight' => 100,
  ];
  $component['name'] = t('Gov Pay');
  $fields['gov_uk_pay']['default'] = _form_builder_webform_default('gov_uk_pay', [], $component);

  return $fields;
}

/**
 * Implements _form_builder_webform_form_builder_preview_alter_component().
 */
function _form_builder_webform_form_builder_preview_alter_gov_uk_pay($form_element) {
  $content = isset($form_element["#webform_component"]["extra"]["content"]) ?
    $form_element["#webform_component"]["extra"]["content"] :
    NULL;
  $message = 'Gov UK Pay: ';
  if (!$content) {
    $message .= 'No content specified, no message will appear. ';
  }
  $form_element['#markup'] = $message;
  $form_element['#children'] = $message;

  return $form_element;
}

/**
 * Implements _form_builder_webform_form_builder_map_component().
 */
function _form_builder_webform_form_builder_map_gov_uk_pay() {
  return [
    'form_builder_type' => 'gov_uk_pay',
    'properties' => [
      'source' => [
        'storage_parents' => ['extra', 'amount_source'],
      ],
      'fixed_amount' => [
        'storage_parents' => ['extra', 'fixed_amount'],
      ],
      'content' => [
        'storage_parents' => ['extra', 'content'],
      ],
      'button_text' => [
        'storage_parents' => ['extra', 'button_text'],
      ],
      'payment_message' => [
        'storage_parents' => ['extra', 'payment_message'],
      ],
      'confirmation_message' => [
        'storage_parents' => ['extra', 'confirmation_message'],
      ],
    ],
  ];
}
