<?php

function gov_pay_confirmation_form($form, $form_state, $uuid, $nid = NULL, $sid = NULL) {
  $confirmationMessage = NULL;
  $amount = NULL;
  $status = NULL;

  // Find confirmation message from webform component config.
  if (!is_null($nid)) {
    $node = node_load($nid);
    $components = isset($node->webform['components']) ? $node->webform['components'] : NULL;
    $confirmationMessage = NULL;
    if (!is_null($components)) {
      foreach ($components as $cid => $component) {
        if ($component['type'] === 'crm_gov_pay') {
          $confirmationMessage = !empty($component['extra']['confirmation_message'])
            ? $component['extra']['confirmation_message']
            : NULL;
        }
      }
    }
  }

  // Provide default confirmation message.
  if (empty($confirmationMessage)) {
    $confirmationMessage = '
      <div class="infobox infobox-info">
        <div class="content">Thank you for making a payment via GOV.UK Pay.</br>
          If your payment has not shown as complete for over 1 day,
          please contact us with your payment ID.
        </div>
     </div>';
  }

  // Load payment entity from site DB.
  $govPay = new GovPay();
  $fetchPayment = $govPay->fetchGovPayment($uuid);
  module_invoke_all('gov_pay_confirmation', $fetchPayment);

  if (count($fetchPayment) === 1) {
    $payment_ref = reset($fetchPayment);

    // Fetch GOV.UK Pay payment.
    $getPayment = $govPay->getPayment($payment_ref->payment_id);

    // Set Status & Message.
    $paymentStatus = isset($getPayment->state->status)
      ? $getPayment->state->status
      : 'Status not found.';
    $paymentMessage = isset($getPayment->state->message)
      ? $getPayment->state->message
      : '';
    $amount = isset($payment_ref->amount)
      ? '£' . number_format(intval($payment_ref->amount) / 100, 2)
      : 'Payment not found';

    $status = "<div class='payment-status'>
                <strong>$paymentStatus</strong>
               </div>
               <div class='payment-message'>$paymentMessage</div>";
  }

  $form['container'] = [
    '#type' => 'container',
    '#prefix' => "<div class='gov-pay-container'>",
    '#suffix' => "</div>",
  ];
  $form['container']['message'] = [
    '#type' => 'markup',
    '#prefix' => "<div class='gov-pay-confirmation-message'>",
    '#suffix' => "</div>",
    '#markup' => $confirmationMessage,
  ];
  $form['container']['paymentID'] = [
    '#type' => 'markup',
    '#prefix' => "<div class='gov-pay-paymentID'>",
    '#suffix' => "</div>",
    '#markup' => "<b>Payment ID:</b> $uuid",
  ];

  $form['container']['payment'] = [
    '#type' => 'container',
    '#prefix' => "<div class='gov-pay-payment'>",
    '#suffix' => "</div>",
  ];
  $form['container']['payment']['payment_amount'] = [
    '#type' => 'markup',
    '#prefix' => "<div class='gov-pay-payment-amount'>",
    '#suffix' => "</div>",
    '#markup' => "<label>Amount:</label><div class='amount'>$amount</div>",
  ];
  $form['container']['payment']['status'] = [
    '#type' => 'markup',
    '#markup' => "$status",
    '#prefix' => '<div id="gov-pay-payment-status" class="alert-'. $paymentStatus . '">',
    '#suffix' => '</div>',
  ];
  $form['container']['actions'] = [
    '#type' => 'container',
    '#prefix' => "<div class='gov-pay-actions'>",
    '#suffix' => "</div>",
  ];
  $form['container']['actions']['refresh'] = [
    '#type' => 'button',
    '#value' => 'Refresh status',
    '#submit' => [],
    '#ajax' => [
      'callback' => '_gov_pay_confirmation_refresh',
      'wrapper' => 'gov-pay-payment-status',
      'method' => 'replace',
      'effect' => 'fade',
    ],
  ];
  $form['container']['actions']['back'] = [
    '#type' => 'submit',
    '#value' => 'Back to site',
    '#attributes' => [
      'class' => ['button btn btn-default'],
    ],
    '#submit' => ['_gov_pay_confirmation_back'],
  ];

  return $form;
}

function _gov_pay_confirmation_back($form, $form_state) {
  drupal_goto('<front>');
}

function _gov_pay_confirmation_refresh($form, &$form_state) {
  $form_state['rebuild'] = TRUE;
  return $form["container"]["payment"]["status"];
}